# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/).

## [Unreleased]

## [2022.6.0]

### Changed
- migrated to github

## [2022.4.0]

### Added
- initial release

[Unreleased]: https://github.com/yaq-project/yaqd-ekspla/compare/v2022.6.0...main
[2022.6.0]: https://github.com/yaq-project/yaqd-ekspla/compare/v2022.4.0...2022.6.0
[2022.4.0]: https://github.com/yaq-project/yaqd-ekspla/releases/tag/v2022.4.0
